@@ -1,3 +1,5 @@
+#include <R.h>
+
 #include "rmatrix.h"
 #include <iostream>
 using namespace std;
@@ -19,7 +21,7 @@ double& RMatrix::operator() ( unsigned int r, unsigned int c )
 {
 #ifdef DEBUG_RMATRIX
   if( r<0 || r>=R || c<0 || c>=C ) {
-    cout << "Index (" << r << "," << c << ") is out of range (" << R << "," << C << "). Seg-fault, R choose you!" << endl;
+    Rprintf("Index (%d,%d) is out of range (%d,%d). Likely to crash R.\n", r, c, R, C);
   }
 #endif
   return( data[ r + c*R ] );
@@ -29,7 +31,7 @@ double& RMatrix::elt( unsigned r, unsigned c )
 {
 #ifdef DEBUG_RMATRIX
   if( r<0 || r>=R || c<0 || c>=C ) {
-    cout << "Index (" << r << "," << c << ") is out of range (" << R << "," << C << "). Seg-fault, R choose you!" << endl;
+    Rprintf("Index (%d,%d) is out of range (%d,%d). Likely to crash R.\n", r, c, R, C);
   }
 #endif
   return( data[ r + c*R ] );
